==> moodle-1.4.3-pgsql.tgz: moodle/lang/no_gr/survey.php <==
<?php


$string['actual'] = "Faktisk";
$string['actualclass'] = "Faktisk kurs";
$string['actualstudent'] = "Faktisk \$a";
$string['allquestions'] = "Alle sprsml i rekkeflge, alle elever";
$string['allscales'] = "Alle skalaer, alle elever";
$string['alreadysubmitted'] = "Du har allerede besvart denne underskelsen";
$string['analysisof'] = "Analyse av \$a";
$string['answers'] = "Svar";
$string['attls1'] = "Nr jeg evaluerer hva noen sier fokuserer jeg p innholdet i argumentet og ikke personen som framfrer det.";
$string['attls10'] = "Det er viktig for meg  vre s objektiv som mulig nr jeg vurderer noe.";
$string['attls10short'] = " vre objektiv";
$string['attls11'] = "Jeg prver  tenke med folk i stedet for mot dem.";
$string['attls11short'] = "tenke MED folk";
$string['attls12'] = "Jeg har spesielle kriterier jeg bruker nr jeg vurderer argumenter.";
$string['attls12short'] = "bruker kriterier for  vurdere";
$string['attls13'] = "Det er mer sannsynlig at jeg prver  forst andres mening enn at jeg prver  vurdere den.";
$string['attls13short'] = "forske  forst";
$string['attls14'] = "Jeg prver  finne svakheter i andre folks tankegang for  hjelpe dem  klargjre deres argumenter.";
$string['attls14short'] = "finne svakheter";
$string['attls15'] = "Jeg bruker  'g i andres sko' nr jeg diskuterer kontroversielle temaer for  se hvorfor de tenker som de gjr.";
$string['attls15short'] = "g i andres sko";
$string['attls16'] = "Man kan si at min mte  analysere p er  sette dem p prve fordi jeg er nye med  vurdere alle beviser.";
$string['attls16short'] = "sette p prve";
$string['attls17'] = "Jeg finner bruk av logikk og fornuft mer verdifull enn tanker som angr meg personlig nr jeg lser problemer.";
$string['attls17short'] = "jeg verdsetter logikk mest";
$string['attls18'] = "Jeg kan f innsikt i meninger som er ulike mine egene med bruk av empati.";
$string['attls18short'] = "bruk av empati";
$string['attls19'] = "Nr jeg mter folk med meninger som virker fremmed for meg gjr jeg en stor innsats for  'vre' den personen for  se hvorfor de kan ha slike meninger.";
$string['attls19short'] = "innsats for  'vre' person";
$string['attls1short'] = "fokusere p argumentets kvalitet";
$string['attls2'] = "Jeg liker  spille djevelens advokat - argumenterer det motsatte av hva folk sier.";
$string['attls20'] = "Jeg bruker tid p  tenke p hva som er 'feil' med ting. For eksempel leter jeg etter noe i litteratur jeg leser for  finne noe som ikke er godt nok grunngitt.";
$string['attls20short'] = "hva er feil?";
$string['attls2short'] = "spille djevelens advokat";
$string['attls3'] = "Jeg liker  forst hvor andre folk 'kommer fra'; hvilke opplevelser og erfaringer som gjr at de tenker og fler som de gjr.";
$string['attls3short'] = "hvor folk kommer fra";
$string['attls4'] = "Den viktigste delen av min utdanning har vrt  lre og forst folk som er svrt forskjellig fra meg.";
$string['attls4short'] = "forst forskjellige folk";
$string['attls5'] = "Jeg fler at den beste mten  f min egen identitet er  samarbeide med andre, varierte typer mennesker.";
$string['attls5short'] = "samarbeide variert";
$string['attls6'] = "Jeg liker  hre meningen til folk med bakgrunn ulik fra min - det hjelper meg  forst hvordan samme sak kan ses p p ulike mter.";
$string['attls6short'] = "liker  hre meninger";
$string['attls7'] = "Jeg ser at jeg styrker min egen posisjon nr jeg argumenterer med noen jeg er uenig med.";
$string['attls7short'] = "styrker med argumentasjon";
$string['attls8'] = "Jeg er alltid interessert i  vite hvorfor folk sier og tror som de gjr.";
$string['attls8short'] = "vite hvorfor folk sier og tror";
$string['attls9'] = "Jeg tar meg selv ofte i  argumentere mot forfattere av bker jeg leser for logisk  forst hvorfor de tar feil.";
$string['attls9short'] = "argumentere mot forfattere";
$string['attlsintro'] = "Meningen med denne underskelsen er  hjelpe oss  evaluere dine holdninger til tenking og lring.

Det er ingen 'riktige' eller 'gale' svar; vi er bare interessert i din mening. Svarene blir behandlet strengt konfidensielt og vil ikke pvirke dine resultater i kurset.";
$string['attlsm1'] = "Holdninger til tenking og lring";
$string['attlsm2'] = "Koblet lring";
$string['attlsm3'] = "Separat lring";
$string['attlsmintro'] = "I diskusjon...";
$string['attlsname'] = "ATTLS (20 delers versjon)";
$string['clicktocontinue'] = "Klikk her for  fortsette";
$string['clicktocontinuecheck'] = "Klikk her for  markere og fortsette";
$string['colles1'] = "lringen min fokuserer p temaer som interesserer meg.";
$string['colles10'] = "jeg ber andre elever om  forklare deres ider.";
$string['colles10short'] = "jeg ber om forklaringer";
$string['colles11'] = "andre elever ber meg om  forklare mine ider.";
$string['colles11short'] = "jeg blir bedt om  forklare";
$string['colles12'] = "andre elever gir tilbakemelding p mine ider.";
$string['colles12short'] = "elever gir meg tilbakemelding";
$string['colles13'] = "lreren stimulerer tenkingen min.";
$string['colles13short'] = "lrer stimulerer tenking";
$string['colles14'] = "lreren oppmuntrer meg til  delta.";
$string['colles14short'] = "lrer oppmuntrer meg";
$string['colles17'] = "andre elever oppmuntrer meg til  delta.";
$string['colles17short'] = "elever oppmuntrer meg";
$string['colles18'] = "andre elever setter pris p mine bidrag.";
$string['colles18short'] = "elever setter pris p meg";
$string['colles19'] = "andre elever finner verdi i mine bidrag.";
$string['colles19short'] = "elever finner verdi i meg";
$string['colles1short'] = "fokus p interessante temaer";
$string['colles2'] = "det jeg lrer er viktig for min profesjonelle praksis.";
$string['colles20'] = "andre elever forstr min kamp for  lre.";
$string['colles20short'] = "elever forstr";
$string['colles21'] = "jeg forstr godt det andre elever sier.";
$string['colles21short'] = "jeg forstr andre elever";
$string['colles22'] = "andre elever forstr godt det jeg sier.";
$string['colles22short'] = "elever forstr meg";
$string['colles23'] = "jeg forstr godt det lreren sier";
$string['colles23short'] = "jeg forstr lreren";
$string['colles24'] = "lreren forstr godt det jeg sier.";
$string['colles24short'] = "lreren forstr meg";
$string['colles2short'] = "viktig for min praksis";
$string['colles3'] = "jeg lrer  forbedre min profesjonelle praksis.";
$string['colles3short'] = "forbedre min praksis";
$string['colles4'] = "det jeg lrer har god tilknytning til min profesjonelle praksis.";
$string['colles4short'] = "tilknytning til min praksis";
$string['colles5'] = "jeg tenker kritisk p hvordan jeg lrer.";
$string['colles5short'] = "kritisk til min lring";
$string['colles6'] = "eg tenker kritisk p mine ider.";
$string['colles6short'] = "kritisk til egne ider";
$string['colles7'] = "jeg tenker kritisk p andre elevers ider.";
$string['colles7short'] = "kritisk til andre elever";
$string['colles8'] = "jeg tenker kritisk p idene i det jeg leser.";
$string['colles8short'] = "kritisk til det jeg leser";
$string['colles9'] = "jeg forklarer mine ider til andre elever.";
$string['colles9short'] = "jeg forklarer ider";
$string['collesaintro'] = "Meningen med denne underskelsen er  hjelpe oss  forst hvor bra nettpresentasjonen av dette kurset ga deg mulighet til  lre. 

Hver av de 24 pstandene under spr etter dine erfaringer med dette kurset.

Det er ingen 'riktige' eller 'gale' svar; vi er bare interessert i din mening. Dine svar vil bli behandlet konfidensielt og vil ikke pvirke resultatet ditt i kurset.

Dine nye gjennomtenkte svar vil hjelpe oss  forbedre mten dette kurset blir presentert i framtiden.

Tusen takk.";
$string['collesapintro'] = "Meningen med denne underskelsen er  hjelpe oss  forst hvor bra nettpresentasjonen av dette kurset ga deg mulighet til  lre. 

Hver av de 24 pstandene under ber deg sammenligne dine <B>nskede</B> (ideelle) og <B>faktiske</B> erfaringer i dette kurset.

Det er ingen 'riktige' eller 'gale' svar; vi er bare interessert i din mening. Dine svar vil bli behandlet konfidensielt og vil ikke pvirke resultatet ditt i kurset.

Dine nye gjennomtenkte svar vil hjelpe oss  forbedre mten dette kurset blir presentert i framtiden.

Tusen takk.";
$string['collesm1'] = "Relevans";
$string['collesm1short'] = "Relevans";
$string['collesm2'] = "Reflekterende tenking";
$string['collesm2short'] = "Reflekterende tenking";
$string['collesm3'] = "Interaktivitet";
$string['collesm3short'] = "Interaktivitet";
$string['collesm4'] = "Lrersttte";
$string['collesm4short'] = "Lrersttte";
$string['collesmintro'] = "I dette nettkursett...";
$string['collespintro'] = "Meningen med denne underskelsen er  hjelpe oss  forst hva du finner verdifullt i lring over internett.

Hver av de 24 pstandene under spr etter dine <B>foretrukne</B> (ideelle) erfaringer i dette kurset.

Det er ingen 'riktige' eller 'gale' svar; vi er bare interessert i din mening. Svarene vil bli behandlet konfidensielt og vil ikke pvirke dine resultater.

Dine nye gjennomtenkte svar vil hjelpe oss i  forbedre dette kurset i framtiden.

Tusen takk.";
$string['collespname'] = "COLLES (foretrukket)";
$string['done'] = "Ferdig";
$string['download'] = "Last ned";
$string['downloadexcel'] = "Last ned data som Excel-regneark";
$string['downloadinfo'] = "Du kan laste ned de komplette dataene fra denne underskelsen for bruk i Excel, SPSS eller lignende.";
$string['downloadtext'] = "Last ned data som ren tekst-fil";
$string['editingasurvey'] = "Redigere en underskelse";
$string['guestsnotallowed'] = "Gjester kan ikke svare p denne underskelsen";
$string['helpsurveys'] = "Hjelp til ulike underskelser";
$string['howlong'] = "Hvor lang tid tok det  svare p denne underskelsen?";
$string['howlongoptions'] = "under 1 min,1-2 min,2-3 min,3-4 min,4-5-min,5-10 min,mer enn 10";
$string['ifoundthat'] = "Jeg fant ut at";
$string['introtext'] = "Intro-tekst";
$string['ipreferthat'] = "Jeg foretrekker at";
$string['modulename'] = "Underskelse";
$string['modulenameplural'] = "Underskelser";
$string['name'] = "Navn";
$string['newsurveyresponses'] = "Nye besvarelser";
$string['nobodyyet'] = "Ingen har besvart denne underskelsen enda";
$string['notdone'] = "Ikke ferdig enda";
$string['notes'] = "Dine egne analyser og notater";
$string['othercomments'] = "Har du noen andre kommentarer?";
$string['peoplecompleted'] = "\$a personer har besvart denne underskelsen s langt";
$string['preferred'] = "Foretrukket";
$string['preferredclass'] = "Foretrukket kurs";
$string['preferredstudent'] = "Foretrukket \$a";
$string['question'] = "Sprsml";
$string['questions'] = "Sprsml";
$string['questionsnotanswered'] = "Noen av flere valg-sprsmlene er ikke besvart.";
$string['report'] = "Underskelse-rapport";
$string['savednotes'] = "Dine notater ble lagret";
$string['scaleagree5'] = "Svrt uenig,Litt uenig,Verken enig eller uenig,Litt enig,Svrt enig";
$string['scales'] = "Skalaer";
$string['scaletimes5'] = "Nesten aldri,Sjelden,Noen ganger,Ofte,Nesten alltid";
$string['seemoredetail'] = "Klikk her for detaljer";
$string['selectedquestions'] = "Valgte sprsml fra en skala, alle elevene";
$string['summary'] = "Sammendrag";
$string['surveycompleted'] = "Du har fullfrt denne underskelsen. Grafen under viser et sammendrag av dine resultater sammenlignet med kursets gjennomsnitt.";
$string['surveyname'] = "Navn p underskelse";
$string['surveysaved'] = "Underskelse lagret";
$string['surveytype'] = "Type underskelse";
$string['thanksforanswers'] = "Takk for at du svarte p denne underskelsen, \$a";
$string['time'] = "Tid";
$string['viewsurveyresponses'] = "Vis \$a svar p underskelse";

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/no_gr/survey.php <==
<?php


$string['actual'] = "Faktisk";
$string['actualclass'] = "Faktisk kurs";
$string['actualstudent'] = "Faktisk \$a";
$string['allquestions'] = "Alle sprsml i rekkeflge, alle elever";
$string['allscales'] = "Alle skalaer, alle elever";
$string['alreadysubmitted'] = "Du har allerede besvart denne underskelsen";
$string['analysisof'] = "Analyse av \$a";
$string['answers'] = "Svar";
$string['attls1'] = "Nr jeg evaluerer hva noen sier fokuserer jeg p innholdet i argumentet og ikke personen som framfrer det.";
$string['attls10'] = "Det er viktig for meg  vre s objektiv som mulig nr jeg vurderer noe.";
$string['attls10short'] = " vre objektiv";
$string['attls11'] = "Jeg prver  tenke med folk i stedet for mot dem.";
$string['attls11short'] = "tenke MED folk";
$string['attls12'] = "Jeg har spesielle kriterier jeg bruker nr jeg vurderer argumenter.";
$string['attls12short'] = "bruker kriterier for  vurdere";
$string['attls13'] = "Det er mer sannsynlig at jeg prver  forst andres mening enn at jeg prver  vurdere den.";
$string['attls13short'] = "forske  forst";
$string['attls14'] = "Jeg prver  finne svakheter i andre folks tankegang for  hjelpe dem  klargjre deres argumenter.";
$string['attls14short'] = "finne svakheter";
$string['attls15'] = "Jeg bruker  'g i andres sko' nr jeg diskuterer kontroversielle temaer for  se hvorfor de tenker som de gjr.";
$string['attls15short'] = "g i andres sko";
$string['attls16'] = "Man kan si at min mte  analysere p er  sette dem p prve fordi jeg er nye med  vurdere alle beviser.";
$string['attls16short'] = "sette p prve";
$string['attls17'] = "Jeg finner bruk av logikk og fornuft mer verdifull enn tanker som angr meg personlig nr jeg lser problemer.";
$string['attls17short'] = "jeg verdsetter logikk mest";
$string['attls18'] = "Jeg kan f innsikt i meninger som er ulike mine egene med bruk av empati.";
$string['attls18short'] = "bruk av empati";
$string['attls19'] = "Nr jeg mter folk med meninger som virker fremmed for meg gjr jeg en stor innsats for  'vre' den personen for  se hvorfor de kan ha slike meninger.";
$string['attls19short'] = "innsats for  'vre' person";
$string['attls1short'] = "fokusere p argumentets kvalitet";
$string['attls2'] = "Jeg liker  spille djevelens advokat - argumenterer det motsatte av hva folk sier.";
$string['attls20'] = "Jeg bruker tid p  tenke p hva som er 'feil' med ting. For eksempel leter jeg etter noe i litteratur jeg leser for  finne noe som ikke er godt nok grunngitt.";
$string['attls20short'] = "hva er feil?";
$string['attls2short'] = "spille djevelens advokat";
$string['attls3'] = "Jeg liker  forst hvor andre folk 'kommer fra'; hvilke opplevelser og erfaringer som gjr at de tenker og fler som de gjr.";
$string['attls3short'] = "hvor folk kommer fra";
$string['attls4'] = "Den viktigste delen av min utdanning har vrt  lre og forst folk som er svrt forskjellig fra meg.";
$string['attls4short'] = "forst forskjellige folk";
$string['attls5'] = "Jeg fler at den beste mten  f min egen identitet er  samarbeide med andre, varierte typer mennesker.";
$string['attls5short'] = "samarbeide variert";
$string['attls6'] = "Jeg liker  hre meningen til folk med bakgrunn ulik fra min - det hjelper meg  forst hvordan samme sak kan ses p p ulike mter.";
$string['attls6short'] = "liker  hre meninger";
$string['attls7'] = "Jeg ser at jeg styrker min egen posisjon nr jeg argumenterer med noen jeg er uenig med.";
$string['attls7short'] = "styrker med argumentasjon";
$string['attls8'] = "Jeg er alltid interessert i  vite hvorfor folk sier og tror som de gjr.";
$string['attls8short'] = "vite hvorfor folk sier og tror";
$string['attls9'] = "Jeg tar meg selv ofte i  argumentere mot forfattere av bker jeg leser for logisk  forst hvorfor de tar feil.";
$string['attls9short'] = "argumentere mot forfattere";
$string['attlsintro'] = "Meningen med denne underskelsen er  hjelpe oss  evaluere dine holdninger til tenking og lring.

Det er ingen 'riktige' eller 'gale' svar; vi er bare interessert i din mening. Svarene blir behandlet strengt konfidensielt og vil ikke pvirke dine resultater i kurset.";
$string['attlsm1'] = "Holdninger til tenking og lring";
$string['attlsm2'] = "Koblet lring";
$string['attlsm3'] = "Separat lring";
$string['attlsmintro'] = "I diskusjon...";
$string['attlsname'] = "ATTLS (20 delers versjon)";
$string['clicktocontinue'] = "Klikk her for  fortsette";
$string['clicktocontinuecheck'] = "Klikk her for  markere og fortsette";
$string['colles1'] = "lringen min fokuserer p temaer som interesserer meg.";
$string['colles10'] = "jeg ber andre elever om  forklare deres ider.";
$string['colles10short'] = "jeg ber om forklaringer";
$string['colles11'] = "andre elever ber meg om  forklare mine ider.";
$string['colles11short'] = "jeg blir bedt om  forklare";
$string['colles12'] = "andre elever gir tilbakemelding p mine ider.";
$string['colles12short'] = "elever gir meg tilbakemelding";
$string['colles13'] = "lreren stimulerer tenkingen min.";
$string['colles13short'] = "lrer stimulerer tenking";
$string['colles14'] = "lreren oppmuntrer meg til  delta.";
$string['colles14short'] = "lrer oppmuntrer meg";
$string['colles17'] = "andre elever oppmuntrer meg til  delta.";
$string['colles17short'] = "elever oppmuntrer meg";
$string['colles18'] = "andre elever setter pris p mine bidrag.";
$string['colles18short'] = "elever setter pris p meg";
$string['colles19'] = "andre elever finner verdi i mine bidrag.";
$string['colles19short'] = "elever finner verdi i meg";
$string['colles1short'] = "fokus p interessante temaer";
$string['colles2'] = "det jeg lrer er viktig for min profesjonelle praksis.";
$string['colles20'] = "andre elever forstr min kamp for  lre.";
$string['colles20short'] = "elever forstr";
$string['colles21'] = "jeg forstr godt det andre elever sier.";
$string['colles21short'] = "jeg forstr andre elever";
$string['colles22'] = "andre elever forstr godt det jeg sier.";
$string['colles22short'] = "elever forstr meg";
$string['colles23'] = "jeg forstr godt det lreren sier";
$string['colles23short'] = "jeg forstr lreren";
$string['colles24'] = "lreren forstr godt det jeg sier.";
$string['colles24short'] = "lreren forstr meg";
$string['colles2short'] = "viktig for min praksis";
$string['colles3'] = "jeg lrer  forbedre min profesjonelle praksis.";
$string['colles3short'] = "forbedre min praksis";
$string['colles4'] = "det jeg lrer har god tilknytning til min profesjonelle praksis.";
$string['colles4short'] = "tilknytning til min praksis";
$string['colles5'] = "jeg tenker kritisk p hvordan jeg lrer.";
$string['colles5short'] = "kritisk til min lring";
$string['colles6'] = "eg tenker kritisk p mine ider.";
$string['colles6short'] = "kritisk til egne ider";
$string['colles7'] = "jeg tenker kritisk p andre elevers ider.";
$string['colles7short'] = "kritisk til andre elever";
$string['colles8'] = "jeg tenker kritisk p idene i det jeg leser.";
$string['colles8short'] = "kritisk til det jeg leser";
$string['colles9'] = "jeg forklarer mine ider til andre elever.";
$string['colles9short'] = "jeg forklarer ider";
$string['collesaintro'] = "Meningen med denne underskelsen er  hjelpe oss  forst hvor bra nettpresentasjonen av dette kurset ga deg mulighet til  lre. 

Hver av de 24 pstandene under spr etter dine erfaringer med dette kurset.

Det er ingen 'riktige' eller 'gale' svar; vi er bare interessert i din mening. Dine svar vil bli behandlet konfidensielt og vil ikke pvirke resultatet ditt i kurset.

Dine nye gjennomtenkte svar vil hjelpe oss  forbedre mten dette kurset blir presentert i framtiden.

Tusen takk.";
$string['collesapintro'] = "Meningen med denne underskelsen er  hjelpe oss  forst hvor bra nettpresentasjonen av dette kurset ga deg mulighet til  lre. 

Hver av de 24 pstandene under ber deg sammenligne dine <b>nskede</b> (ideelle) og <b>faktiske</b> erfaringer i dette kurset.

Det er ingen 'riktige' eller 'gale' svar; vi er bare interessert i din mening. Dine svar vil bli behandlet konfidensielt og vil ikke pvirke resultatet ditt i kurset.

Dine nye gjennomtenkte svar vil hjelpe oss  forbedre mten dette kurset blir presentert i framtiden.

Tusen takk.";
$string['collesm1'] = "Relevans";
$string['collesm1short'] = "Relevans";
$string['collesm2'] = "Reflekterende tenking";
$string['collesm2short'] = "Reflekterende tenking";
$string['collesm3'] = "Interaktivitet";
$string['collesm3short'] = "Interaktivitet";
$string['collesm4'] = "Lrersttte";
$string['collesm4short'] = "Lrersttte";
$string['collesmintro'] = "I dette nettkursett...";
$string['collespintro'] = "Meningen med denne underskelsen er  hjelpe oss  forst hva du finner verdifullt i lring over internett.

Hver av de 24 pstandene under spr etter dine <b>foretrukne</b> (ideelle) erfaringer i dette kurset.

Det er ingen 'riktige' eller 'gale' svar; vi er bare interessert i din mening. Svarene vil bli behandlet konfidensielt og vil ikke pvirke dine resultater.

Dine nye gjennomtenkte svar vil hjelpe oss i  forbedre dette kurset i framtiden.

Tusen takk.";
$string['collespname'] = "COLLES (foretrukket)";
$string['done'] = "Ferdig";
$string['download'] = "Last ned";
$string['downloadexcel'] = "Last ned data som Excel-regneark";
$string['downloadinfo'] = "Du kan laste ned de komplette dataene fra denne underskelsen for bruk i Excel, SPSS eller lignende.";
$string['downloadtext'] = "Last ned data som ren tekst-fil";
$string['editingasurvey'] = "Redigere en underskelse";
$string['guestsnotallowed'] = "Gjester kan ikke svare p denne underskelsen";
$string['helpsurveys'] = "Hjelp til ulike underskelser";
$string['howlong'] = "Hvor lang tid tok det  svare p denne underskelsen?";
$string['howlongoptions'] = "under 1 min,1-2 min,2-3 min,3-4 min,4-5-min,5-10 min,mer enn 10";
$string['ifoundthat'] = "Jeg fant ut at";
$string['introtext'] = "Intro-tekst";
$string['ipreferthat'] = "Jeg foretrekker at";
$string['modulename'] = "Underskelse";
$string['modulenameplural'] = "Underskelser";
$string['name'] = "Navn";
$string['newsurveyresponses'] = "Nye besvarelser";
$string['nobodyyet'] = "Ingen har besvart denne underskelsen enda";
$string['notdone'] = "Ikke ferdig enda";
$string['notes'] = "Dine egne analyser og notater";
$string['othercomments'] = "Har du noen andre kommentarer?";
$string['peoplecompleted'] = "\$a personer har besvart denne underskelsen s langt";
$string['preferred'] = "Foretrukket";
$string['preferredclass'] = "Foretrukket kurs";
$string['preferredstudent'] = "Foretrukket \$a";
$string['question'] = "Sprsml";
$string['questions'] = "Sprsml";
$string['questionsnotanswered'] = "Noen av flere valg-sprsmlene er ikke besvart.";
$string['report'] = "Underskelse-rapport";
$string['savednotes'] = "Dine notater ble lagret";
$string['scaleagree5'] = "Svrt uenig,Litt uenig,Verken enig eller uenig,Litt enig,Svrt enig";
$string['scales'] = "Skalaer";
$string['scaletimes5'] = "Nesten aldri,Sjelden,Noen ganger,Ofte,Nesten alltid";
$string['seemoredetail'] = "Klikk her for detaljer";
$string['selectedquestions'] = "Valgte sprsml fra en skala, alle elevene";
$string['summary'] = "Sammendrag";
$string['surveycompleted'] = "Du har fullfrt denne underskelsen. Grafen under viser et sammendrag av dine resultater sammenlignet med kursets gjennomsnitt.";
$string['surveyname'] = "Navn p underskelse";
$string['surveysaved'] = "Underskelse lagret";
$string['surveytype'] = "Type underskelse";
$string['thanksforanswers'] = "Takk for at du svarte p denne underskelsen, \$a";
$string['time'] = "Tid";
$string['viewsurveyresponses'] = "Vis \$a svar p underskelse";

?>
